@@ -11,6 +11,7 @@ from Perdy.pretty import prettyPrint
 from Perdy.parser import printXML
 from Perdy.pyxbext import directory
 from Argumental.Argue import Argue
+from GoldenChild.xpath import *
 
 logger = Logger()
 args = Argue()
@@ -201,6 +202,47 @@ class COD(object):
 			self.__show(childItem, checkboxes=checkboxes, shownotes=shownotes)
 			
 
+	def _reorganize(self, cod, node):
+		#print('%s, %s'%(node.name, type(node)))
+
+		parents = [
+			'Document',
+			'BaseVersion',
+			'Properties',
+			'content',
+			'ChildItem',
+		]
+
+		if node.name in parents:
+			children = dict()
+
+			for child in getElements(cod.ctx, '*', node):
+				#print('\t%s, %s'%(child.name, type(child)))
+				children[child.name] = child
+				child.unlinkNode()
+			for name in sorted(children.keys()):
+				node.addChild(children[name])
+		
+		for element in getElements(cod.ctx, '*', node):
+			self._reorganize(cod, element)
+				
+
+				
+	@args.operation
+	def reorganize(self, file):
+		if not file.endswith('cod'):
+			sys.stderr.write('not a cod file\n')
+			return
+		#print(file)
+		
+		cod = XML(*getContextFromFile(file))
+
+		self._reorganize(cod, cod.doc.getRootElement())
+		
+		with open(file, 'w') as output:
+			printXML(str(cod.doc), output=output)
+		
+
 	#........................................................
 	@logger.debug
 	@args.operation
@@ -216,6 +258,8 @@ class COD(object):
 		'''
 		load a cod file and display
 		'''
+		self.reorganize(file)
+		
 		if blackAndWhite:
 			for key in list(self.xcolours.keys()):
 				self.xcolours[key] = ''
